mb/google/geralt: Use BOE_TV110C9M_LL0 as default mipi panel

We will use BOE_TV110C9M_LL0 for geralt proto board, so update the
panel setting.

BUG=none
TEST=emerge-geralt coreboot;
     see panel-BOE_TV110C9M_LL0 in coreboot.rom

Signed-off-by: Bo-Chen Chen <rex-bc.chen@mediatek.com>
Change-Id: I28e9dd87350b55fdc609dd2c562c5a2ad578187c
Reviewed-on: https://review.coreboot.org/c/coreboot/+/71786
Reviewed-by: Yu-Ping Wu <yupingso@google.com>
Reviewed-by: Yidi Lin <yidilin@google.com>
Tested-by: build bot (Jenkins) <no-reply@coreboot.org>
diff --git a/src/mainboard/google/geralt/Kconfig b/src/mainboard/google/geralt/Kconfig
index d6a9796..8de4fea 100644
--- a/src/mainboard/google/geralt/Kconfig
+++ b/src/mainboard/google/geralt/Kconfig
@@ -31,6 +31,7 @@
 	select MAINBOARD_HAS_NATIVE_VGA_INIT
 	select HAVE_LINEAR_FRAMEBUFFER
 	select RTC
+	select MIPI_PANEL_BOE_TV110C9M_LL0 if BOARD_GOOGLE_GERALT
 
 config MAINBOARD_DIR
 	string
diff --git a/src/mainboard/google/geralt/panel_geralt.c b/src/mainboard/google/geralt/panel_geralt.c
index 33e1540..bbb1060 100644
--- a/src/mainboard/google/geralt/panel_geralt.c
+++ b/src/mainboard/google/geralt/panel_geralt.c
@@ -20,9 +20,9 @@
 	/* TODO: Add edp aux backlight for MUTTO_B152731E1 when we get MUTTO_B152731E1 */
 }
 
-static void power_on_mipi_boe_nv110c9m_l60(void)
+static void power_on_mipi_boe_tv110c9m_ll0(void)
 {
 	/* TODO: Add the poweron for BOE_NV110C9M_L60 when we get BOE_NV110C9M_L60 */
 }
 
 static void power_on_edp_mutto_b152731e1(void)
@@ -32,8 +32,8 @@
 
 static struct panel_description panels[] = {
 	[1] = {
-		.name = "BOE_NV110C9M_L60",
-		.power_on = power_on_mipi_boe_nv110c9m_l60,
+		.name = "BOE_TV110C9M_LL0",
+		.power_on = power_on_mipi_boe_tv110c9m_ll0,
 		.configure_panel_backlight = configure_mipi_pwm_backlight,
 		.disp_path = DISP_PATH_MIPI,
 		.pwm_ctrl_gpio = true,
@@ -20,9 +20,9 @@
 {
-	/* TODO: Add the poweron for BOE_NV110C9M_L60 when we get BOE_NV110C9M_L60 */
+	/* TODO: Add the poweron for BOE_TV110C9M_LL0 when we get BOE_TV110C9M_LL0 */
 }
 